pub struct CostTrackerStream<P: Producer> { /* private fields */ }Expand description
Reports through an InventoryTracker, which hashes each ObjectId both to
anonymize it and to decide whether it is sampled. See objectstore_inventory_tracker
for the record format.
Logs, counts, and swallows errors returned by the InventoryTracker.
Implementations
Sourceimpl<P: Producer> CostTrackerStream<P>
impl<P: Producer> CostTrackerStream<P>
Sourcepub fn new(producer: P, config: &CostTrackerStreamConfig) -> Self
pub fn new(producer: P, config: &CostTrackerStreamConfig) -> Self
Reports changes through producer, as described by config.