ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 18 variants InvalidMetadata, InvalidUploadId, ClientStream, RangeNotSatisfiable { total: u64, }, UploadOffsetMismatch { offset: u64, }, UploadSessionGone, UnknownUploadSession, ChunkExceedsUploadLength { offset: u64, content_length: u64, upload_length: u64, }, AtCapacity, Unsupported, BackendFailure, BackendRateLimited, BackendTimeout, BackendUnavailable, Panic, UnexpectedTombstone, CorruptData, Internal,
}
The client-visible semantic classification of a service error.

Variants



InvalidMetadata

Object metadata supplied by a client is invalid.



InvalidUploadId

A multipart upload identifier is invalid.



ClientStream

A client-provided request stream failed.



RangeNotSatisfiable

A requested byte range cannot be resolved against the object size.

Fields

total: u64

Total object length in bytes.



UploadOffsetMismatch

A resumable chunk starts at a different offset than the backend currently holds.

Fields

offset: u64

The offset the backend currently holds.



UploadSessionGone

A resumable upload session expired or was canceled.



UnknownUploadSession

The backend does not recognize a resumable upload session.



ChunkExceedsUploadLength

A resumable chunk would exceed the total upload length.

Fields

offset: u64

The offset at which the chunk would be written.

content_length: u64

The declared length of the chunk.

upload_length: u64

The total upload length declared when the session was created.



AtCapacity

The service cannot accept more work.



Unsupported

The requested operation is unsupported.



BackendFailure

A storage backend operation failed.



BackendRateLimited

A storage backend rejected the operation because it is rate limited.



BackendTimeout

A storage backend operation timed out.



BackendUnavailable

A storage backend is temporarily unavailable.



Panic

A service task panicked.



UnexpectedTombstone

A redirect tombstone was encountered by a read that does not support tombstones.



CorruptData

Persisted or remote data is corrupt.



Internal

An unexpected internal service failure occurred.