ObjectContext

Struct ObjectContext 

pub struct ObjectContext {
    pub usecase: String,
    pub scopes: Scopes,
}
Defines where an object, or batch of objects, belongs within the object store.

This is part of the full object identifier for single objects, see ObjectId.

Fields

usecase: String

The usecase, or “product” this object belongs to.

This can be defined on-the-fly by the client, but special server logic (such as the concrete backend/bucket) can be tied to this as well.

scopes: Scopes

The scopes of the object, used for compartmentalization and authorization.

Scopes are hierarchical key-value pairs that act as containers for objects. The first, top-level scope can contain sub scopes, like a structured nested folder system. As such, scopes are used for isolation and access authorization.

Ordering

Note that the order of scopes matters! For example, organization=17,project=42 indicates that project 42 is part of organization 17. If an object were created with these scopes reversed, it counts as a different object.

Not every object within a usecase needs to have the same scopes. It is perfectly valid to create objects with disjunct or a subset of scopes. However, by convention, we recommend to use the same scopes for all objects within a usecase where possible.

Creation

To create scopes, collect from an iterator of Scopes. Since scopes must be validated, you must use Scope::create to create them:

use objectstore_service::id::ObjectContext;
use objectstore_types::scope::{Scope, Scopes};

let object_id = ObjectContext {
    usecase: "my_usecase".to_string(),
    scopes: Scopes::from_iter([
        Scope::create("organization", "17").unwrap(),
        Scope::create("project", "42").unwrap(),
    ]),
};