pub struct CreateUploadSessionResponse {
pub session: SessionToken,
pub granularity: u64,
}Expand description
A newly opened resumable upload session and its upload granularity.
Fields
session: SessionTokenThe encrypted token used to continue the upload.
granularity: u64The upload granularity in bytes, or zero when there is none.