pub enum ChangePhase {
Recovered,
Recorded,
Written,
Lost,
Updated,
Completed,
}Expand description
Phase of a multi-step storage change.
Variants
Recovered
The change was recovered from changelog and the phase is unknown.
Recorded
The change is recorded in the log and LT upload has started.
Written
LT upload has succeeded and the tombstone is being updated.
Lost
The tombstone update failed due to a conflict.
Updated
The tombstone update succeeded.
Completed
Cleanup complete.
Implementations
Sourceimpl ChangePhase
impl ChangePhase
Sourcepub fn compare_and_write(succeeded: bool) -> Self
pub fn compare_and_write(succeeded: bool) -> Self
Returns the phase corresponding to the outcome of a compare-and-write operation.