pub struct CountingBackend { /* private fields */ }Expand description
A Backend decorator that counts each operation performed for COGS. Also implements
MultipartUploadBackend. See the module documentation for how it should be used.
CountingBackend’s implementation clashes with how the MultipartUploadBackend trait is
connected to the Backend trait. The workaround is to give CountingBackend (up to) two
Arcs that point to the inner backend:
inner: Arc<dyn Backend>inner_multipart: Option<Arc<dyn MultipartUploadBackend>>ifinnersupports it
Implementations
Sourceimpl CountingBackend
impl CountingBackend
Sourcepub fn new(inner: Box<dyn Backend>) -> Self
pub fn new(inner: Box<dyn Backend>) -> Self
Creates a CountingBackend that wraps inner and increments cogs.usage
before delegating operations to it.