pub enum Error {
Io(Error),
Serde {
context: String,
cause: Error,
},
Reqwest {
context: String,
cause: Error,
},
Metadata(Error),
GcpAuth(Error),
Panic(String),
Dropped,
AtCapacity,
Generic {
context: String,
cause: Option<Box<dyn Error + Send + Sync>>,
},
}Expand description
Error type for service operations.
Variants
Io(Error)
IO errors related to payload streaming or file operations.
Serde
Errors related to de/serialization.
Fields
Reqwest
All errors stemming from the reqwest client, used in multiple backends to send requests to e.g. GCP APIs. These can be network errors encountered when sending the requests, but can also indicate errors returned by the API itself.
Fields
cause: ErrorThe underlying reqwest error.
Metadata(Error)
Errors related to de/serialization and parsing of object metadata.
GcpAuth(Error)
Errors encountered when attempting to authenticate with GCP.
Panic(String)
A spawned service task panicked.
Dropped
A spawned service task was dropped before it could deliver its result.
This is an unexpected condition that can occur when the runtime drops the task for unknown reasons.
AtCapacity
The service has reached its concurrency limit and cannot accept more operations.
Generic
Any other error stemming from one of the storage backends, which might be specific to that backend or to a certain operation.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn panic(payload: Box<dyn Any + Send>) -> Self
pub fn panic(payload: Box<dyn Any + Send>) -> Self
Creates an Error::Panic from a panic payload, extracting the message.
Sourcepub fn reqwest(context: impl Into<String>, cause: Error) -> Self
pub fn reqwest(context: impl Into<String>, cause: Error) -> Self
Creates an Error::Reqwest from a reqwest error with context.
Sourcepub fn generic(context: impl Into<String>) -> Self
pub fn generic(context: impl Into<String>) -> Self
Creates an Error::Generic with a context string and no cause.